package com.xydl.cac.filter;

import lombok.extern.slf4j.Slf4j;
import org.apache.commons.compress.utils.Lists;
import org.springframework.stereotype.Component;
import org.springframework.util.AntPathMatcher;
import org.springframework.util.PathMatcher;
import org.springframework.web.filter.OncePerRequestFilter;

import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Enumeration;
import java.util.List;

@Component
@Slf4j
public class UrlFilter extends OncePerRequestFilter {

    PathMatcher pathMatcher = new AntPathMatcher();
    private List<String> urlWhiteList = Arrays.asList("/swagger**", "/webjars/**", "/v3/api-docs/**", "/swagger-resources/**",
            "/static**");

    @Override
    protected void doFilterInternal(HttpServletRequest request, HttpServletResponse response, FilterChain filterChain) throws ServletException, IOException {
        String path = request.getRequestURI();
        for (String white : urlWhiteList) {
            if (pathMatcher.match(white, path)) {
                filterChain.doFilter(request, response);
                return;
            }
        }

        StringBuilder str = new StringBuilder(path + " called");
        Enumeration<String> params = request.getParameterNames();
        while (params.hasMoreElements()) {
            String paramName = params.nextElement();
            str.append(", ").append(paramName).append("=").append(request.getParameter(paramName));
        }
        log.info(str.toString());
        filterChain.doFilter(request, response);
    }
}
